#' Calculate Persistent Homology with Ripser-Based Engines
#'
#' Ports Ripser-based persistent homology calculation engines
#' from C++ to R using the Rcpp package.
#'
#' @useDynLib ripserr
#' @importFrom Rcpp sourceCpp
#' @name ripserr
"_PACKAGE"
